import { ServiceConfig as ServiceConfig$1 } from '@cleavelandprice/ngx-lib/authentication';
import * as i0 from '@angular/core';
import { EventEmitter, Injectable, Optional, Output, NgModule, SkipSelf } from '@angular/core';
import * as i2 from '@angular/common/http';
import { CommonModule } from '@angular/common';

const defaultConfig = {
    apiUrl: 'http://utilityapi/authenticate',
    tokenName: 'user'
};

class ServiceConfig extends ServiceConfig$1 {
}

class AuthenticationObjectService {
    //#endregion
    //#region Lifecycle
    // If a ServiceConfig object is not provided when the module is imported, then default values are pulled in from default-config.ts.
    constructor(config, http) {
        this.config = config;
        this.http = http;
        //#region Fields
        this.authenticatedChanged = new EventEmitter();
        this.authenticatingChanged = new EventEmitter();
        this.authenticationError = new EventEmitter();
        this.authenticating = false; // Flag set to true while the service is attempting to authenticate the user
        this.authenticated = false; // Flag set to true when the user is successfully authenticated
        this.authenticatedUser = null; // Object representing the authenticated user
        this.config = {
            ...defaultConfig,
            ...this.config
        };
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    //Authenticate the user and store the token in Local Storage
    login(username, password, adminGroup) {
        const request = {
            username: username,
            password: password,
            adminGroup: adminGroup
        };
        this.authenticating = true;
        this.authenticatingChanged.emit(this.authenticating);
        this.http.post(this.config.apiUrl, request)
            .subscribe({
            next: (user) => {
                if (user) {
                    this.validateUser(user);
                }
                else {
                    this.logout();
                }
            },
            error: (err) => {
                this.authenticating = false;
                this.authenticatingChanged.emit(this.authenticating);
                this.authenticationError.emit(err);
            }
        });
    }
    //Logout the user and delete the token from Local Storage
    logout() {
        if (localStorage.getItem(this.config.tokenName)) {
            localStorage.removeItem(this.config.tokenName);
        }
        this.authenticatedUser = null;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    }
    validateUser(token) {
        this.authenticatedUser = {
            admin: false,
            displayName: token.displayName,
            accountName: token.sAMAccountName,
            distinguishedName: token.distinguishedName,
            employeeNumber: token.employeeNumber,
            memberOf: token.memberOf.join(',')
        };
        localStorage.setItem(this.config.tokenName, JSON.stringify(token));
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    }
    checkForExistingToken() {
        const token = localStorage.getItem(this.config.tokenName);
        if (token) {
            this.validateUser(JSON.parse(token));
        }
    }
}
AuthenticationObjectService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationObjectService, deps: [{ token: ServiceConfig, optional: true }, { token: i2.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
AuthenticationObjectService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationObjectService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationObjectService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: ServiceConfig, decorators: [{
                    type: Optional
                }] }, { type: i2.HttpClient }]; }, propDecorators: { authenticatedChanged: [{
                type: Output
            }], authenticatingChanged: [{
                type: Output
            }], authenticationError: [{
                type: Output
            }] } });

class AuthenticationObjectModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationObjectModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(config) {
        return {
            ngModule: AuthenticationObjectModule,
            providers: [
                AuthenticationObjectService,
                { provide: ServiceConfig, useValue: config }
            ]
        };
    }
}
AuthenticationObjectModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationObjectModule, deps: [{ token: AuthenticationObjectModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
AuthenticationObjectModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationObjectModule, imports: [CommonModule] });
AuthenticationObjectModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationObjectModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationObjectModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule
                    ],
                    exports: []
                }]
        }], ctorParameters: function () { return [{ type: AuthenticationObjectModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }]; } });

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationObjectModule, AuthenticationObjectService, ServiceConfig, defaultConfig };
//# sourceMappingURL=cleavelandprice-ngx-lib-authentication-object.mjs.map
